# Changelog

## 0.1.4

* Type stub fix

## 0.1.3

* Type stub fixes

## 0.1.2

* Minor style and documentation improvements
* Added type information

## 0.1.1

* Minor style and documentation improvements

## 0.1.0

* First beta release
